Welcome to PyKern
=================

PyKern is an application support framework to simplify and to speed development of
Python programs and servers.

PyKern defines policies, which make it easy to eliminate boiler-plate.

.. autosummary::
   :toctree: _autosummary
   :recursive:

.. toctree::
   :maxdepth: 2

   pykern
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
